@@ -27,17 +27,18 @@ class Provider(BaseProvider):
         self.domain_id = self.options['domain']
 
     def create_record(self, type, name, content):
-        record = {
-            'type': type,
-            'name': self._relative_name(name),
-            'data': content,
+        # check if record already exists
+        if len(self.list_records(type, name, content)) == 0:
+            record = {
+                'type': type,
+                'name': self._relative_name(name),
+                'data': content,
 
-        }
-        if type == 'CNAME':
-            record['data'] = record['data'].rstrip('.') + '.' # make sure a the data is always a FQDN for CNAMe.
-
-        payload = self._post('/domains/{0}/records'.format(self.domain_id), record)
+            }
+            if type == 'CNAME':
+                record['data'] = record['data'].rstrip('.') + '.' # make sure a the data is always a FQDN for CNAMe.
 
+            payload = self._post('/domains/{0}/records'.format(self.domain_id), record)
         logger.debug('create_record: %s', True)
         return True
 
@@ -98,14 +99,17 @@ class Provider(BaseProvider):
     # Delete an existing record.
     # If record does not exist, do nothing.
     def delete_record(self, identifier=None, type=None, name=None, content=None):
+        delete_record_id = []
         if not identifier:
             records = self.list_records(type, name, content)
-            logger.debug('records: %s', records)
-            if len(records) == 1:
-                identifier = records[0]['id']
-            else:
-                raise Exception('Record identifier could not be found.')
-        payload = self._delete('/domains/{0}/records/{1}'.format(self.domain_id, identifier))
+            delete_record_id = [record['id'] for record in records]
+        else:
+            delete_record_id.append(identifier)
+        
+        logger.debug('delete_records: %s', delete_record_id)
+        
+        for record_id in delete_record_id:
+            payload = self._delete('/domains/{0}/records/{1}'.format(self.domain_id, record_id))
 
         # is always True at this point, if a non 200 response is returned an error is raised.
         logger.debug('delete_record: %s', True)
